@@ -9,7 +9,6 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <netdb.h>
 #include <stdlib.h> 
 #include <getopt.h> 
 #include "ipv6calc.h"
@@ -157,7 +156,7 @@ int main(int argc,char *argv[]) {
 	argv += optind;
 	argc -= optind;
 
-//	fprintf(stderr, "Command value: %lx\n", command); 
+/*	fprintf(stderr, "Command value: %lx\n", command); */
 	
 	/* do work depending on selection */
 	if (command & CMD_printversion) {
