@@ -1,15 +1,19 @@
 /*
- * Version:     $Id: ipv6calc.h,v 0.21 2001/04/08 $
+ * Version:     $Id: ipv6calc.h,v 0.22 2001/04/22 $
  *
  * Author:      Peter Bieringer <pb@bieringer.de>
  *
  */ 
 
-/* global definitions */
+/* global program related definitions */
 #define PROGRAM_NAME "ipv6calc"
-#define PROGRAM_VERSION "0.21"
+#define PROGRAM_VERSION "0.22"
 #define PROGRAM_COPYRIGHT "(P) & (C) 2001 by Peter Bieringer <pb@bieringer.de>\n published under GNU GPL"
 
+/*** global definitions ***/
+/* max length of a string for storage in a char array */
+#define NI_MAXHOST 1024
+
 /* external functions */
 extern int  addr_to_ip6int(char *addrstring, char *resultstring);
 extern void addr_to_ip6int_printhelp();
@@ -49,22 +53,22 @@ extern void mac_to_eui64_printhelp();
 extern void mac_to_eui64_printhelplong();
 
 /* debug switches */
-//#define DEBUG_addr_to_ip6int
-//#define DEBUG_addr_to_compressed
-//#define DEBUG_addr_to_uncompressed
-//#define DEBUG_addr_to_fulluncompressed
-//#define DEBUG_addr_to_ifinet6
-//#define DEBUG_ifinet6_to_compressed
-//#define DEBUG_addr_to_base85
-//#define DEBUG_base85_to_addr
-//#define DEBUG_mac_to_eui64
+/* #define DEBUG_addr_to_ip6int */
+/* #define DEBUG_addr_to_compressed */
+/* #define DEBUG_addr_to_uncompressed */
+/* #define DEBUG_addr_to_fulluncompressed */
+/* #define DEBUG_addr_to_ifinet6 */
+/* #define DEBUG_ifinet6_to_compressed */
+/* #define DEBUG_addr_to_base85 */
+/* #define DEBUG_base85_to_addr */
+/* #define DEBUG_mac_to_eui64 */
 
 /* debug switches for libaries */
-//#define DEBUG_librfc1884
-//#define DEBUG_librfc1924
-//#define DEBUG_libipv6calc
-//#define DEBUG_libmac
-//#define DEBUG_libeui64
+/* #define DEBUG_librfc1884 */
+/* #define DEBUG_librfc1924 */
+/* #define DEBUG_libipv6calc */
+/* #define DEBUG_libmac */
+/* #define DEBUG_libeui64 */
 
 
 /* command values */
@@ -90,14 +94,14 @@ extern void mac_to_eui64_printhelplong();
 
 /* structures */
 typedef struct {
-	u_int16_t addr6[8];		/* IPv6 address in 8x 16 bit */
-	u_int8_t prefixlength;	/* prefix length (0-128) */
-	int flag_prefixuse;			/* =1 prefix length in use */
-	u_int16_t scope;					/* address scope value */
+	unsigned int addr6[8];			/* IPv6 address in 8x 16 bit */
+	unsigned short prefixlength;	/* prefix length (0-128) 8 bit*/
+	int flag_prefixuse;				/* =1 prefix length in use */
+	unsigned int scope;				/* address scope value 16 bit*/
 } ipv6calc_ipv6addr;
 
 typedef struct {
-	u_int8_t addr[6];		/* MAC address in 6x 8 bit */
+	unsigned int addr[6];		/* MAC address in 6x 8 bit */
 } ipv6calc_macaddr;
 
 /* libipv6calc */
