@@ -3,7 +3,7 @@
  *  A function to format a given MAC address to a
  *   EUI-64 identifier
  *
- * Version:		$Id: mac_to_eui64.c,v 0.15 2001/03/12 $
+ * Version:		$Id: mac_to_eui64.c,v 0.20 2001/04/08 $
  * 
  * Author:		Peter Bieringer <pb@bieringer.de>
  *
@@ -56,7 +56,7 @@ int mac_to_eui64(char *addrstring, char *resultstring) {
 		return (retval);
 	};
 
-	result = ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring);
+	result = ipv6addrstruct_to_uncompaddrsuffix(&ipv6addr, resultstring);
    
 	retval = 0;
 	return (retval);
